@@ -14,12 +14,29 @@ Puppet::Type.newtype(:ring_object_device) do
       # we have to have URI Scheme so we just add http:// and ignore it later
       uri = URI('http://' + value)
       address = uri.host
-      port_device = uri.port
       if ['','/'].include?(uri.path)
         raise(Puppet::Error, "namevar should contain a device")
       end
       IPAddr.new(address)
     end
+
+    munge do |value|
+      # If storage policy_index is specified first strip that off.
+      # Resource name is not required to start with a policy_index
+      if !value.split(/^\d+:/)[1].nil?
+        value_without_policy = value.split(/^\d+:/)[1]
+      else
+        value_without_policy = value
+      end
+      # we have to have URI Scheme so we just add http:// and ignore it later
+      uri = URI('http://' + value_without_policy)
+      ip = IPAddr.new(uri.host)
+      if ip.ipv6?
+        value.gsub(uri.host, '[' + ip.to_s + ']')
+      else
+        value
+      end
+    end
   end
 
   newproperty(:region)
