@@ -33,13 +33,11 @@ describe 'swift::client' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({
-          :fqdn           => 'some.host.tld',
-        }))
+        facts.merge(OSDefaults.get_facts())
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-swiftclient' }
         when 'RedHat'
