@@ -138,7 +138,7 @@ describe 'swift::proxy::ceilometer' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :ceilometermiddleware_package_name => 'python3-ceilometermiddleware' }
         when 'RedHat'
