@@ -43,7 +43,7 @@ describe 'swift::proxy' do
           :provider  => nil,
           :enable    => true,
           :hasstatus => true,
-          :tag       => 'swift-service',
+          :tag       => ['swift-service', 'swift-proxy-service'],
         )}
 
         it { should contain_service('swift-proxy-server').that_subscribes_to('Anchor[swift::service::begin]') }
@@ -106,8 +106,6 @@ describe 'swift::proxy' do
               include swift::proxy::copy
             "
           end
-
-          it { should contain_swift_proxy_config('foo/bar').with_value('foo').that_notifies('Anchor[swift::config::end]') }
         end
 
         describe 'when more parameters are set' do
@@ -316,29 +314,21 @@ describe 'swift::proxy' do
             :ensure   => (param_hash[:manage_service] && param_hash[:enabled]) ? 'running' : 'stopped',
             :enable   => param_hash[:enabled],
             :provider => nil,
-            :tag      => 'swift-service',
+            :tag      => ['swift-service', 'swift-proxy-service'],
           )
         end
       end
     end
 
-    context 'with disabled service managing and service provider' do
+    context 'with disabled service management' do
       before do
         params.merge!({
-          :manage_service   => false,
-          :enabled          => false,
-          :service_provider => 'swiftinit',
+          :manage_service => false,
         })
       end
 
-      it 'configures swift-proxy-server service' do
-        should contain_service('swift-proxy-server').with(
-          :ensure    => nil,
-          :name      => 'swift-proxy-server',
-          :provider  => 'swiftinit',
-          :enable    => false,
-          :hasstatus => true,
-        )
+      it 'does not configure swift-proxy-server service' do
+        should_not contain_service('swift-proxy-server')
       end
     end
   end
@@ -352,7 +342,7 @@ describe 'swift::proxy' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { 'swift-proxy-server' => 'swift-proxy' }
         when 'RedHat'
