@@ -7,18 +7,6 @@ describe 'swift::storage::server' do
     "
   end
 
-  let :default_params do
-    {
-      :devices         => '/srv/node',
-      :owner           => 'swift',
-      :group           => 'swift',
-      :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-      :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-      :max_connections => '25',
-      :log_requests    => true
-    }
-  end
-
   shared_examples 'swift::storage::server' do
     describe 'with an invalid title' do
       let :params do
@@ -97,9 +85,12 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_sample_rate_factor').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_metric_prefix').with_value('<SERVICE DEFAULT>')
 
+        is_expected.to contain_swift_account_config('account-auditor/').with_ensure('present')
+        is_expected.to contain_swift_account_config('account-replicator/').with_ensure('present')
         is_expected.to contain_swift_account_config('account-replicator/rsync_module').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('account-replicator/concurrency').with_value(1)
         is_expected.to contain_swift_account_config('account-replicator/interval').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_account_config('account-reaper/').with_ensure('present')
         is_expected.to contain_swift_account_config('account-reaper/concurrency').with_value(1)
       }
 
@@ -129,29 +120,54 @@ describe 'swift::storage::server' do
             :rsync_module_per_device => true,
             :device_names            => ['sda', 'sdb'],
           })
-
-          it { is_expected.to contain_rsync__server__module('account_sda').with(
-            :path            => '/srv/node',
-            :lock_file       => '/var/lock/account_sda.lock',
-            :uid             => 'swift',
-            :gid             => 'swift',
-            :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :max_connections => 25,
-            :read_only       => false,
-          )}
-          it { is_expected.to contain_rsync__server__module('account_sdb').with(
-            :path            => '/srv/node',
-            :lock_file       => '/var/lock/account_sdb.lock',
-            :uid             => 'swift',
-            :gid             => 'swift',
-            :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :max_connections => 25,
-            :read_only       => false,
-          )}
-          it { is_expected.to contain_swift_account_config('account-replicator/rsync_module').with_value('{replication_ip}::account_{device}') }
         end
+
+        it { is_expected.to contain_rsync__server__module('account_sda').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/account_sda.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :max_connections => 25,
+          :read_only       => false,
+        )}
+        it { is_expected.to contain_rsync__server__module('account_sdb').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/account_sdb.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :max_connections => 25,
+          :read_only       => false,
+        )}
+        it { is_expected.to contain_swift_account_config('account-replicator/rsync_module').with_value('{replication_ip}::account_{device}') }
+      end
+
+      context 'with rsync parameters' do
+        before do
+          params.merge!({
+            :max_connections => 100,
+            :hosts_allow     => '192.0.2.0/25',
+            :hosts_deny      => '192.0.2.128/25',
+            :incoming_chmod  => '0644',
+            :outgoing_chmod  => '0644',
+          })
+        end
+
+        it { is_expected.to contain_rsync__server__module('account').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/account.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :hosts_allow     => '192.0.2.0/25',
+          :hosts_deny      => '192.0.2.128/25',
+          :incoming_chmod  => '0644',
+          :outgoing_chmod  => '0644',
+          :max_connections => 100,
+          :read_only       => false,
+        )}
       end
     end
 
@@ -218,10 +234,14 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_container_config('DEFAULT/log_statsd_metric_prefix').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_swift_container_config('DEFAULT/allowed_sync_hosts').with_value('127.0.0.1')
+        is_expected.to contain_swift_container_config('container-auditor/').with_ensure('present')
+        is_expected.to contain_swift_container_config('container-replicator/').with_ensure('present')
         is_expected.to contain_swift_container_config('container-replicator/rsync_module').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('container-replicator/concurrency').with_value(1)
         is_expected.to contain_swift_container_config('container-replicator/interval').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_config('container-updater/').with_ensure('present')
         is_expected.to contain_swift_container_config('container-updater/concurrency').with_value(1)
+        is_expected.to contain_swift_container_config('container-sharder/').with_ensure('present')
         is_expected.to contain_swift_container_config('container-sharder/auto_shard').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('container-sharder/concurrency').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('container-sharder/interval').with_value('<SERVICE DEFAULT>')
@@ -253,29 +273,54 @@ describe 'swift::storage::server' do
             :rsync_module_per_device => true,
             :device_names            => ['sda', 'sdb'],
           })
-
-          it { is_expected.to contain_rsync__server__module('container_sda').with(
-            :path            => '/srv/node',
-            :lock_file       => '/var/lock/container_sda.lock',
-            :uid             => 'swift',
-            :gid             => 'swift',
-            :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :max_connections => 25,
-            :read_only       => false,
-          )}
-          it { is_expected.to contain_rsync__server__module('container_sdb').with(
-            :path            => '/srv/node',
-            :lock_file       => '/var/lock/container_sdb.lock',
-            :uid             => 'swift',
-            :gid             => 'swift',
-            :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :max_connections => 25,
-            :read_only       => false,
-          )}
-          it { is_expected.to contain_swift_container_config('container-replicator/rsync_module').with_value('{replication_ip}::container_{device}') }
         end
+
+        it { is_expected.to contain_rsync__server__module('container_sda').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/container_sda.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :max_connections => 25,
+          :read_only       => false,
+        )}
+        it { is_expected.to contain_rsync__server__module('container_sdb').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/container_sdb.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :max_connections => 25,
+          :read_only       => false,
+        )}
+        it { is_expected.to contain_swift_container_config('container-replicator/rsync_module').with_value('{replication_ip}::container_{device}') }
+      end
+
+      context 'with rsync parameters' do
+        before do
+          params.merge!({
+            :max_connections => 100,
+            :hosts_allow     => '192.0.2.0/25',
+            :hosts_deny      => '192.0.2.128/25',
+            :incoming_chmod  => '0644',
+            :outgoing_chmod  => '0644',
+          })
+        end
+
+        it { is_expected.to contain_rsync__server__module('container').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/container.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :hosts_allow     => '192.0.2.0/25',
+          :hosts_deny      => '192.0.2.128/25',
+          :incoming_chmod  => '0644',
+          :outgoing_chmod  => '0644',
+          :max_connections => 100,
+          :read_only       => false,
+        )}
       end
     end
 
@@ -347,13 +392,17 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_object_config('DEFAULT/client_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('app:object-server/splice').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('app:object-server/mb_per_sync').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_object_config('object-auditor/').with_ensure('present')
         is_expected.to contain_swift_object_config('object-auditor/disk_chunk_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_object_config('object-replicator/').with_ensure('present')
         is_expected.to contain_swift_object_config('object-replicator/rsync_module').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('object-replicator/rsync_module').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('object-replicator/concurrency').with_value(1)
         is_expected.to contain_swift_object_config('object-replicator/rsync_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_object_config('object-replicator/rsync_bwlimit').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_object_config('object-updater/').with_ensure('present')
         is_expected.to contain_swift_object_config('object-updater/concurrency').with_value(1)
+        is_expected.to contain_swift_object_config('object-reconstructor/').with_ensure('present')
       }
 
       context 'with customized pipeline' do
@@ -382,29 +431,54 @@ describe 'swift::storage::server' do
             :rsync_module_per_device => true,
             :device_names            => ['sda', 'sdb'],
           })
-
-          it { is_expected.to contain_rsync__server__module('object_sda').with(
-            :path            => '/srv/node',
-            :lock_file       => '/var/lock/object_sda.lock',
-            :uid             => 'swift',
-            :gid             => 'swift',
-            :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :max_connections => 25,
-            :read_only       => false,
-          )}
-          it { is_expected.to contain_rsync__server__module('object_sdb').with(
-            :path            => '/srv/node',
-            :lock_file       => '/var/lock/object_sdb.lock',
-            :uid             => 'swift',
-            :gid             => 'swift',
-            :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-            :max_connections => 25,
-            :read_only       => false,
-          )}
-          it { is_expected.to contain_swift_object_config('object-replicator/rsync_module').with_value('{replication_ip}::object_{device}') }
         end
+
+        it { is_expected.to contain_rsync__server__module('object_sda').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/object_sda.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :max_connections => 25,
+          :read_only       => false,
+        )}
+        it { is_expected.to contain_rsync__server__module('object_sdb').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/object_sdb.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :incoming_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :outgoing_chmod  => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+          :max_connections => 25,
+          :read_only       => false,
+        )}
+        it { is_expected.to contain_swift_object_config('object-replicator/rsync_module').with_value('{replication_ip}::object_{device}') }
+      end
+
+      context 'with rsync parameters' do
+        before do
+          params.merge!({
+            :max_connections => 100,
+            :hosts_allow     => '192.0.2.0/25',
+            :hosts_deny      => '192.0.2.128/25',
+            :incoming_chmod  => '0644',
+            :outgoing_chmod  => '0644',
+          })
+        end
+
+        it { is_expected.to contain_rsync__server__module('object').with(
+          :path            => '/srv/node',
+          :lock_file       => '/var/lock/object.lock',
+          :uid             => 'swift',
+          :gid             => 'swift',
+          :hosts_allow     => '192.0.2.0/25',
+          :hosts_deny      => '192.0.2.128/25',
+          :incoming_chmod  => '0644',
+          :outgoing_chmod  => '0644',
+          :max_connections => 100,
+          :read_only       => false,
+        )}
       end
     end
   end
