@@ -1,30 +1,5 @@
-$LOAD_PATH.push(
-  File.join(
-    File.dirname(__FILE__),
-    '..',
-    '..',
-    '..',
-    'fixtures',
-    'modules',
-    'inifile',
-    'lib')
-)
-$LOAD_PATH.push(
-  File.join(
-    File.dirname(__FILE__),
-    '..',
-    '..',
-    '..',
-    'fixtures',
-    'modules',
-    'openstacklib',
-    'lib')
-)
-
 require 'spec_helper'
-
 provider_class = Puppet::Type.type(:swift_drive_audit_config).provider(:ini_setting)
-
 describe provider_class do
 
   it 'should default to the default setting when no other one is specified' do
